<?php
namespace Ondc\Exportcsv\Block;

use Ondc\Exportcsv\Helper\Data as ModuleHelper;
use Magento\Framework\App\Filesystem\DirectoryList;

class Exportcsv extends \Magento\Framework\View\Element\Template
{
    const IS_MODULE_ENABLED   = 'ondc/check/active';
    const CSV_EMAIL   = 'ondc/check/csvemail';
    

     /**
     * @var ModuleHelper
     */
    private $moduleHelper;

    protected $fileFactory;
	protected $csvProcessor;
	protected $directoryList;

    /**
     * @var \Magento\Framework\HTTP\Client\Curl $curl
     */
    protected $curl;
        
    public function __construct(       
        \Magento\Framework\View\Element\Template\Context $context,
        \Psr\Log\LoggerInterface $logger,
        ModuleHelper $moduleHelper,
        \Magento\Framework\HTTP\Client\Curl $curl,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
    	\Magento\Framework\App\Response\Http\FileFactory $fileFactory,
    	\Magento\Framework\File\Csv $csvProcessor,
        \Magento\Framework\App\Filesystem\DirectoryList $directoryList,
        \Magento\Framework\Filesystem $filesystem,
        array $data = []
    )
    {        
        $this->scopeConfig = $scopeConfig;
        $this->curl = $curl;
        $this->_logger = $logger;
        $this->moduleHelper = $moduleHelper;
        $this->fileFactory = $fileFactory;
    	$this->csvProcessor = $csvProcessor;
        $this->directory = $filesystem->getDirectoryWrite(DirectoryList::VAR_DIR);
    	$this->directoryList = $directoryList;
        parent::__construct($context, $data);
    }

    public function getReadyOndcProducts()
    {
        $logger = $this->moduleHelper->isLogged();
        $moduleIsEnabled = $this->moduleHelper->getConfigValue(self::IS_MODULE_ENABLED);
        $storeDomain = ($this->moduleHelper->getConfigValue(self::STORE_DOMAIN)) ? $this->moduleHelper->getConfigValue(self::STORE_DOMAIN) : "";
        if($moduleIsEnabled){
            // Get the current date and the previous day in the required format
            $currentDate = date("Y-m-d", strtotime('now'));
            try{
                    $tokenGeneration = $this->getOauthTocken();
                    $searchCriteria = 'searchCriteria[pageSize]=1000&searchCriteria[currentPage]=1';
                    $base_uri = $storeDomain.'rest/V1/products?'.$searchCriteria;
                
                    $headers = [
                        "Content-Type" => "application/json",
                        "Authorization" => "Bearer" .$tokenGeneration
                        ];

                    if($tokenGeneration){
                        $logdata = array(
                            $headers,
                            "Url" => $base_uri
                        );
                        $logger->info('Enquiry Request Data Json :: '.json_encode($logdata));
                    }  

                    $allProducts = [];
                    $ch = curl_init();

                    curl_setopt_array($ch, array(
                        CURLOPT_URL => $base_uri,
                        CURLOPT_RETURNTRANSFER => true,
                        CURLOPT_ENCODING => '',
                        CURLOPT_MAXREDIRS => 10,
                        CURLOPT_TIMEOUT => 0,
                        CURLOPT_FOLLOWLOCATION => true,
                        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                        CURLOPT_CUSTOMREQUEST => 'GET',
                        CURLOPT_HTTPHEADER => $headers,
                      ));

                    $response = curl_exec($ch);    
                    //$logger->info('Enquiry Request Data Json :: '.json_encode($response));
                    //$this->_logger->log(100,print_r($response,true)); 
                      
                    //$this->_logger->log(100,print_r($response,true)); 
                    curl_close($ch); 
                //return ['products' => $allProducts];
                return $response;
            } catch (\Exception $e) {
                $this->_logger->info($e->getMessage());
            }
        }else{
            $logger->info("Ondc logger :: Module is disabled");
        }
    
    }

    /**
     * @getOauthTocken() => Oauth Token generated here for Authrization ....
    */
    public function getOauthTocken(){ 
        $logger = $this->moduleHelper->isLogged();
        
        $storeDomain = ($this->moduleHelper->getConfigValue(self::STORE_DOMAIN)) ? $this->moduleHelper->getConfigValue(self::STORE_DOMAIN) : "";
        $storeUser = ($this->moduleHelper->getConfigValue(self::API_USER)) ? $this->moduleHelper->getConfigValue(self::API_USER) : "";
        $storePassword = ($this->moduleHelper->getConfigValue(self::API_PASSWORD)) ? $this->moduleHelper->getConfigValue(self::API_PASSWORD) : "";
        $url = $storeDomain.'rest/V1/integration/admin/token/';
        
        $headers = ["Content-Type" => "application/json"];

        $curl = curl_init();

        curl_setopt_array($curl, array(
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => array('username' => $storeUser,'password' => $storePassword),
            CURLOPT_HTTPHEADER => $headers,
          ));

        $response = curl_exec($curl);
        curl_close($curl);
        //$this->_logger->log(100,print_r($response,true));
        return $response;
    }
  
}
?>