<?php
namespace Ondc\Exportcsv\Helper;

use \Magento\Store\Model\ScopeInterface;
use \Magento\Store\Model\StoreManagerInterface;

use Magento\Framework\Mail\Template\TransportBuilder;
use Magento\Framework\Translate\Inline\StateInterface;
use \Magento\Framework\Escaper;

class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    const CSV_EMAIL   = 'ondc/check/csvemail';
    const XML_PATH_IDENT_GENERAL_EMAIL = 'trans_email/ident_general/email';
    const XML_PATH_IDENT_GENERAL_NAME = 'trans_email/ident_general/name';

    protected $storeManager;
    protected $transportBuilder;
    protected $inlineTranslation;
    protected $escaper;

    /**
     * Data constructor.
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Store\Model\StoreManagerInterface $storeManager,

        TransportBuilder $transportBuilder,
        StateInterface $state,
        \Magento\Framework\Escaper $escaper,

        \Magento\Framework\App\Helper\Context $context
    ) {
        $this->storeManager=$storeManager;

        $this->transportBuilder = $transportBuilder;
        $this->inlineTranslation = $state;
        $this->escaper = $escaper;

        parent::__construct($context);
    }

    public function getStoreUrl()
    {
        return $this->storeManager->getStore()->getBaseUrl();
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return $this->scopeConfig->isSetFlag(
            'ondc/check/active',
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    public function isLogged()
    {
        $writer = new \Zend_Log_Writer_Stream(BP.'/pub/media/ondc/logs/ondcexportcsvdata.log');
        $logger = new \Zend_Log();
        return $logger->addWriter($writer);
    }

    public function sendOndcCsvEmail($fileName){
        /* Products CSV script */
        $zLogger = $this->isLogged();
        $getProductCsvUrl = $this->getStoreUrl() . 'media/ondc/csv/' . $fileName;
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        try {

            /* Send Email */
            $this->inlineTranslation->suspend();
            $sender = [
            'name' => $this->escaper->escapeHtml($this->scopeConfig->getValue(self::XML_PATH_IDENT_GENERAL_NAME, $storeScope)),
            'email' => $this->escaper->escapeHtml($this->scopeConfig->getValue(self::XML_PATH_IDENT_GENERAL_EMAIL, $storeScope)),
            ];  
            $addTo = explode(",",$this->escaper->escapeHtml($this->scopeConfig->getValue(self::CSV_EMAIL, $storeScope)));               
            $transport = $this->transportBuilder
                ->setTemplateIdentifier('ondc_product_csv_alert')
                ->setTemplateOptions(
                    [
                        'area' => \Magento\Framework\App\Area::AREA_FRONTEND,
                        'store' => $this->storeManager->getStore()->getId()
                    ]
                )
                ->setTemplateVars([
                    'productCsvUrl'  => $getProductCsvUrl,
                ])
                ->setFrom($sender)
                ->addTo($addTo)
                ->getTransport()
                ->sendMessage();
            $this->inlineTranslation->resume();
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }

}